;
;	New Read from Char ROM and brite back to Char RAM Test
;	V1.0 2024 TB
;

ACIA_S 		= $F000
ACIA_D 		= $F001
VIDEO_RAM	= $D000
KEYB 		= $FD00
mode		= $FC
RESET		= $FF00

START_ADR = $0350		; 

	.ORG	START_ADR
	
	
	

L0:	Lda	#0
	sta	mode
	jsr	SET
	jsr	CLS

	jsr	SNUM		; Set 0..255 to screen
	jsr	KEYB		; wait for input
	cmp	#27
	beq	ESC


L1:	lda	#$00
	jsr	CLHRS		; clear 8k of hires ram

	lda	#$01		; Set main display mode
	sta	mode
	jsr	SET

	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC

	ldx	#$00
L2:	lda	#$00		; Text Character ROM section
	jsr	CPSEG
	inx
	cpx	#$08
	bne	L2
	
	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC

	ldx	#$00
L3:	lda	#$01		; Second Semi Character ROM section
	jsr	CPSEG
	inx
	cpx	#$08
	bne	L3
	
	JSR	KEYB		; wait for input
	cmp	#27
	beq	ESC
	
	jmp	L1

	
ESC:	lda	#$00
	sta	mode
	jsr	SET		; Char RAM 4th 1k
	jmp	RESET


; ******************************************************************************

CPSEG:	tay			; Copy 1k Character ROM to RAM (X) of Segment 0..7 (new version)
				; If A=0, take text ROM, if A<>0 take Semi Graph ROM section (for example 4k EPROM)
	txa
	and	#$07
	asl
	asl
	dey
	beq	CPS0
	ora	#$20		; Char ROM within first 2k
	bne	CPS1
CPS0:	ora	#$22		; Char ROM within second 2k
CPS1:	ldy	mode
	sta	mode
	jsr	SET
	sty	mode		; restore for later

	ldy	#$0
CPS2:	lda	VIDEO_RAM,y
	sta	VIDEO_RAM,y
	lda	VIDEO_RAM+$100,y
	sta	VIDEO_RAM+$100,y
	lda	VIDEO_RAM+$200,y
	sta	VIDEO_RAM+$200,y
	lda	VIDEO_RAM+$300,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	CPS2
	jmp	SET
	



; ******************************************************************************

SNUM:
	ldy	#$00			; Set 32x32 Screen with 0,1,2,..

LSN:	tya
	sta	VIDEO_RAM,y
	sta	VIDEO_RAM+$100,y
	sta	VIDEO_RAM+$200,y
	sta	VIDEO_RAM+$300,y
	dey
	bne	LSN
	rts


; ******************************************************************************
		
CLS:
	lda	#$20
CLSA:	ldy	#$00			; Clear 32x32 Screen with $20

LCLS:
	sta	VIDEO_RAM,y
	sta	VIDEO_RAM+$100,y
	sta	VIDEO_RAM+$200,y
	sta	VIDEO_RAM+$300,y
	iny
	bne	LCLS
	rts

; ******************************************************************************
		
CLHRS:
	tax			; Clear 8K HiRes Screen with $ACCU
	lda	#$21
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$25
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$29
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$2D
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$31
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$35
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$39
	sta	mode
	jsr	SET
	txa
	jsr	CLSA		; clear 1k segment of hires ram

	lda	#$3D
	sta	mode
	jsr	SET
	txa
	jmp	CLSA		; clear 1k segment of hires ram
	



; ******************************************************************************

SET:	lda $D000
        sta $D000
        lda $D3FF
        sta $D3FF
        lda mode
        sta $D3FF
        rts
        
